"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import google.protobuf.wrappers_pb2
import sys
import typing
import yandex.cloud.connectionmanager.v1.clickhouse_pb2
import yandex.cloud.connectionmanager.v1.greenplum_pb2
import yandex.cloud.connectionmanager.v1.kafka_pb2
import yandex.cloud.connectionmanager.v1.mongodb_pb2
import yandex.cloud.connectionmanager.v1.mysql_pb2
import yandex.cloud.connectionmanager.v1.opensearch_pb2
import yandex.cloud.connectionmanager.v1.postgresql_pb2
import yandex.cloud.connectionmanager.v1.redis_pb2
import yandex.cloud.connectionmanager.v1.storedoc_pb2
import yandex.cloud.connectionmanager.v1.trino_pb2
import yandex.cloud.connectionmanager.v1.valkey_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _DBType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _DBTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_DBType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    DB_TYPE_UNSPECIFIED: _DBType.ValueType  # 0
    """Unspecified database type."""
    POSTGRESQL: _DBType.ValueType  # 1
    """PostgreSQL database."""
    MYSQL: _DBType.ValueType  # 2
    """MySQL database."""
    CLICKHOUSE: _DBType.ValueType  # 3
    """ClickHouse database."""
    MONGODB: _DBType.ValueType  # 4
    """MongoDB database."""
    KAFKA: _DBType.ValueType  # 5
    """Apache Kafka message broker."""
    REDIS: _DBType.ValueType  # 6
    """Redis in-memory data store."""
    OPENSEARCH: _DBType.ValueType  # 7
    """OpenSearch search engine."""
    TRINO: _DBType.ValueType  # 8
    """Trino distributed SQL query engine."""
    VALKEY: _DBType.ValueType  # 9
    """Valkey in-memory data store."""
    GREENPLUM: _DBType.ValueType  # 10
    """Greenplum data warehouse."""
    STOREDOC: _DBType.ValueType  # 11
    """StoreDoc document store."""

class DBType(_DBType, metaclass=_DBTypeEnumTypeWrapper):
    """Database or service type enumeration."""

DB_TYPE_UNSPECIFIED: DBType.ValueType  # 0
"""Unspecified database type."""
POSTGRESQL: DBType.ValueType  # 1
"""PostgreSQL database."""
MYSQL: DBType.ValueType  # 2
"""MySQL database."""
CLICKHOUSE: DBType.ValueType  # 3
"""ClickHouse database."""
MONGODB: DBType.ValueType  # 4
"""MongoDB database."""
KAFKA: DBType.ValueType  # 5
"""Apache Kafka message broker."""
REDIS: DBType.ValueType  # 6
"""Redis in-memory data store."""
OPENSEARCH: DBType.ValueType  # 7
"""OpenSearch search engine."""
TRINO: DBType.ValueType  # 8
"""Trino distributed SQL query engine."""
VALKEY: DBType.ValueType  # 9
"""Valkey in-memory data store."""
GREENPLUM: DBType.ValueType  # 10
"""Greenplum data warehouse."""
STOREDOC: DBType.ValueType  # 11
"""StoreDoc document store."""
global___DBType = DBType

@typing.final
class ConnectionParams(google.protobuf.message.Message):
    """Connection parameters for various database and service types."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POSTGRESQL_FIELD_NUMBER: builtins.int
    MYSQL_FIELD_NUMBER: builtins.int
    MONGODB_FIELD_NUMBER: builtins.int
    CLICKHOUSE_FIELD_NUMBER: builtins.int
    KAFKA_FIELD_NUMBER: builtins.int
    REDIS_FIELD_NUMBER: builtins.int
    OPENSEARCH_FIELD_NUMBER: builtins.int
    TRINO_FIELD_NUMBER: builtins.int
    VALKEY_FIELD_NUMBER: builtins.int
    GREENPLUM_FIELD_NUMBER: builtins.int
    STOREDOC_FIELD_NUMBER: builtins.int
    @property
    def postgresql(self) -> yandex.cloud.connectionmanager.v1.postgresql_pb2.PostgreSQLConnection:
        """PostgreSQL database connection parameters."""

    @property
    def mysql(self) -> yandex.cloud.connectionmanager.v1.mysql_pb2.MySQLConnection:
        """MySQL database connection parameters."""

    @property
    def mongodb(self) -> yandex.cloud.connectionmanager.v1.mongodb_pb2.MongoDBConnection:
        """MongoDB database connection parameters."""

    @property
    def clickhouse(self) -> yandex.cloud.connectionmanager.v1.clickhouse_pb2.ClickHouseConnection:
        """ClickHouse database connection parameters."""

    @property
    def kafka(self) -> yandex.cloud.connectionmanager.v1.kafka_pb2.KafkaConnection:
        """Apache Kafka message broker connection parameters."""

    @property
    def redis(self) -> yandex.cloud.connectionmanager.v1.redis_pb2.RedisConnection:
        """Redis in-memory data store connection parameters."""

    @property
    def opensearch(self) -> yandex.cloud.connectionmanager.v1.opensearch_pb2.OpenSearchConnection:
        """OpenSearch search engine connection parameters."""

    @property
    def trino(self) -> yandex.cloud.connectionmanager.v1.trino_pb2.TrinoConnection:
        """Trino distributed SQL query engine connection parameters."""

    @property
    def valkey(self) -> yandex.cloud.connectionmanager.v1.valkey_pb2.ValkeyConnection:
        """Valkey in-memory data store connection parameters."""

    @property
    def greenplum(self) -> yandex.cloud.connectionmanager.v1.greenplum_pb2.GreenplumConnection:
        """Greenplum data warehouse connection parameters."""

    @property
    def storedoc(self) -> yandex.cloud.connectionmanager.v1.storedoc_pb2.StoreDocConnection:
        """StoreDoc document store connection parameters."""

    def __init__(
        self,
        *,
        postgresql: yandex.cloud.connectionmanager.v1.postgresql_pb2.PostgreSQLConnection | None = ...,
        mysql: yandex.cloud.connectionmanager.v1.mysql_pb2.MySQLConnection | None = ...,
        mongodb: yandex.cloud.connectionmanager.v1.mongodb_pb2.MongoDBConnection | None = ...,
        clickhouse: yandex.cloud.connectionmanager.v1.clickhouse_pb2.ClickHouseConnection | None = ...,
        kafka: yandex.cloud.connectionmanager.v1.kafka_pb2.KafkaConnection | None = ...,
        redis: yandex.cloud.connectionmanager.v1.redis_pb2.RedisConnection | None = ...,
        opensearch: yandex.cloud.connectionmanager.v1.opensearch_pb2.OpenSearchConnection | None = ...,
        trino: yandex.cloud.connectionmanager.v1.trino_pb2.TrinoConnection | None = ...,
        valkey: yandex.cloud.connectionmanager.v1.valkey_pb2.ValkeyConnection | None = ...,
        greenplum: yandex.cloud.connectionmanager.v1.greenplum_pb2.GreenplumConnection | None = ...,
        storedoc: yandex.cloud.connectionmanager.v1.storedoc_pb2.StoreDocConnection | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["clickhouse", b"clickhouse", "greenplum", b"greenplum", "kafka", b"kafka", "mongodb", b"mongodb", "mysql", b"mysql", "opensearch", b"opensearch", "postgresql", b"postgresql", "redis", b"redis", "storedoc", b"storedoc", "trino", b"trino", "type", b"type", "valkey", b"valkey"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["clickhouse", b"clickhouse", "greenplum", b"greenplum", "kafka", b"kafka", "mongodb", b"mongodb", "mysql", b"mysql", "opensearch", b"opensearch", "postgresql", b"postgresql", "redis", b"redis", "storedoc", b"storedoc", "trino", b"trino", "type", b"type", "valkey", b"valkey"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["type", b"type"]) -> typing.Literal["postgresql", "mysql", "mongodb", "clickhouse", "kafka", "redis", "opensearch", "trino", "valkey", "greenplum", "storedoc"] | None: ...

global___ConnectionParams = ConnectionParams

@typing.final
class LockboxSecret(google.protobuf.message.Message):
    """Reference to a Lockbox secret."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    NEWEST_VERSION_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the Lockbox secret."""
    version: builtins.str
    """Lockbox secret version."""
    newest_version: builtins.str
    """The newest available version of the Lockbox secret."""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        version: builtins.str = ...,
        newest_version: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["id", b"id", "newest_version", b"newest_version", "version", b"version"]) -> None: ...

global___LockboxSecret = LockboxSecret

@typing.final
class LockboxSecretSpec(google.protobuf.message.Message):
    """Specification for creating a new Lockbox secret."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder where the Lockbox secret will be created. If omitted, the secret will be created in the connection's folder."""
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["folder_id", b"folder_id"]) -> None: ...

global___LockboxSecretSpec = LockboxSecretSpec

@typing.final
class Connection(google.protobuf.message.Message):
    """A Connection resource represents a configured connection to a database or service."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    UPDATED_AT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    CREATED_BY_FIELD_NUMBER: builtins.int
    PARAMS_FIELD_NUMBER: builtins.int
    LOCKBOX_SECRET_FIELD_NUMBER: builtins.int
    LOCKBOX_SECRET_SPEC_FIELD_NUMBER: builtins.int
    IS_MANAGED_FIELD_NUMBER: builtins.int
    CAN_USE_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the connection. Generated at creation time."""
    folder_id: builtins.str
    """ID of the folder that the connection belongs to."""
    name: builtins.str
    """Name of the connection."""
    description: builtins.str
    """Description of the connection."""
    created_by: builtins.str
    """ID of the subject which created the connection."""
    is_managed: builtins.bool
    """Whether this connection is managed by the system (e.g. an MDB cluster)."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp."""

    @property
    def updated_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Last update timestamp."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Connection labels as `key:value` pairs."""

    @property
    def params(self) -> global___ConnectionParams:
        """Connection parameters specific to the database or service type."""

    @property
    def lockbox_secret(self) -> global___LockboxSecret:
        """Reference to the Lockbox secret containing connection credentials."""

    @property
    def lockbox_secret_spec(self) -> global___LockboxSecretSpec:
        """Specification for creating a new Lockbox secret."""

    @property
    def can_use(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """Whether the current user can use this connection. Filled only when `with_can_use` has been requested in ListConnectionRequest."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        folder_id: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        updated_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        created_by: builtins.str = ...,
        params: global___ConnectionParams | None = ...,
        lockbox_secret: global___LockboxSecret | None = ...,
        lockbox_secret_spec: global___LockboxSecretSpec | None = ...,
        is_managed: builtins.bool = ...,
        can_use: google.protobuf.wrappers_pb2.BoolValue | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["can_use", b"can_use", "created_at", b"created_at", "lockbox_secret", b"lockbox_secret", "lockbox_secret_spec", b"lockbox_secret_spec", "params", b"params", "secret", b"secret", "secret_spec", b"secret_spec", "updated_at", b"updated_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["can_use", b"can_use", "created_at", b"created_at", "created_by", b"created_by", "description", b"description", "folder_id", b"folder_id", "id", b"id", "is_managed", b"is_managed", "labels", b"labels", "lockbox_secret", b"lockbox_secret", "lockbox_secret_spec", b"lockbox_secret_spec", "name", b"name", "params", b"params", "secret", b"secret", "secret_spec", b"secret_spec", "updated_at", b"updated_at"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["secret", b"secret"]) -> typing.Literal["lockbox_secret"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["secret_spec", b"secret_spec"]) -> typing.Literal["lockbox_secret_spec"] | None: ...

global___Connection = Connection



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class SignatureCertificate(google.protobuf.message.Message):
    """A signature certificate for SAML applications."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[SignatureCertificate._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNSPECIFIED: SignatureCertificate._Status.ValueType  # 0
        """The status is not specified."""
        ACTIVE: SignatureCertificate._Status.ValueType  # 1
        """The certificate is active and can be used for signing."""
        INACTIVE: SignatureCertificate._Status.ValueType  # 2
        """The certificate is inactive and cannot be used for signing."""

    class Status(_Status, metaclass=_StatusEnumTypeWrapper):
        """Represents the current status of a signature certificate."""

    STATUS_UNSPECIFIED: SignatureCertificate.Status.ValueType  # 0
    """The status is not specified."""
    ACTIVE: SignatureCertificate.Status.ValueType  # 1
    """The certificate is active and can be used for signing."""
    INACTIVE: SignatureCertificate.Status.ValueType  # 2
    """The certificate is inactive and cannot be used for signing."""

    ID_FIELD_NUMBER: builtins.int
    APPLICATION_ID_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    FINGERPRINT_FIELD_NUMBER: builtins.int
    NOT_AFTER_FIELD_NUMBER: builtins.int
    NOT_BEFORE_FIELD_NUMBER: builtins.int
    id: builtins.str
    """Unique identifier of the signature certificate."""
    application_id: builtins.str
    """ID of the SAML application that the signature certificate belongs to."""
    status: global___SignatureCertificate.Status.ValueType
    """Current status of the signature certificate."""
    name: builtins.str
    """Name of the signature certificate."""
    description: builtins.str
    """Description of the signature certificate."""
    data: builtins.str
    """Certificate data in PEM format."""
    fingerprint: builtins.str
    """SHA256-fingerprint of the signature certificate."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp."""

    @property
    def not_after(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Time after which the signature certificate is not valid."""

    @property
    def not_before(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Time before which the signature certificate is not valid."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        application_id: builtins.str = ...,
        status: global___SignatureCertificate.Status.ValueType = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        data: builtins.str = ...,
        fingerprint: builtins.str = ...,
        not_after: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        not_before: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at", "not_after", b"not_after", "not_before", b"not_before"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["application_id", b"application_id", "created_at", b"created_at", "data", b"data", "description", b"description", "fingerprint", b"fingerprint", "id", b"id", "name", b"name", "not_after", b"not_after", "not_before", b"not_before", "status", b"status"]) -> None: ...

global___SignatureCertificate = SignatureCertificate



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/organizationmanager/v1/idp/application/saml/application.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/organizationmanager/v1/idp/application/saml/application.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nJyandex/cloud/organizationmanager/v1/idp/application/saml/application.proto\x12\x38yandex.cloud.organizationmanager.v1.idp.application.saml\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dyandex/cloud/validation.proto\"\x97\x08\n\x0b\x41pplication\x12\n\n\x02id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\\\n\x06status\x18\x05 \x01(\x0e\x32L.yandex.cloud.organizationmanager.v1.idp.application.saml.Application.Status\x12\x61\n\x06labels\x18\x06 \x03(\x0b\x32Q.yandex.cloud.organizationmanager.v1.idp.application.saml.Application.LabelsEntry\x12.\n\ncreated_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x63\n\x10service_provider\x18\t \x01(\x0b\x32I.yandex.cloud.organizationmanager.v1.idp.application.saml.ServiceProvider\x12\x65\n\x11security_settings\x18\n \x01(\x0b\x32J.yandex.cloud.organizationmanager.v1.idp.application.saml.SecuritySettings\x12\x65\n\x11\x61ttribute_mapping\x18\x0b \x01(\x0b\x32J.yandex.cloud.organizationmanager.v1.idp.application.saml.AttributeMapping\x12l\n\x15group_claims_settings\x18\x0c \x01(\x0b\x32M.yandex.cloud.organizationmanager.v1.idp.application.saml.GroupClaimsSettings\x12v\n\x1aidentity_provider_metadata\x18\r \x01(\x0b\x32R.yandex.cloud.organizationmanager.v1.idp.application.saml.IdentityProviderMetadata\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"W\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\n\n\x06\x41\x43TIVE\x10\x02\x12\r\n\tSUSPENDED\x10\x03\x12\x0c\n\x08\x44\x45LETING\x10\x04\"b\n\x18IdentityProviderMetadata\x12\x0e\n\x06issuer\x18\x01 \x01(\t\x12\x0f\n\x07sso_url\x18\x02 \x01(\t\x12\x14\n\x0cmetadata_url\x18\x03 \x01(\t\x12\x0f\n\x07slo_url\x18\x04 \x01(\t\"\x97\x02\n\x0fServiceProvider\x12!\n\tentity_id\x18\x01 \x01(\tB\x0e\xe8\xc7\x31\x01\x8a\xc8\x31\x06<=8000\x12r\n\x08\x61\x63s_urls\x18\x02 \x03(\x0b\x32U.yandex.cloud.organizationmanager.v1.idp.application.saml.AssertionConsumerServiceURLB\t\x82\xc8\x31\x05\x31-100\x12m\n\x08slo_urls\x18\x03 \x03(\x0b\x32P.yandex.cloud.organizationmanager.v1.idp.application.saml.SingleLogoutServiceURLB\t\x82\xc8\x31\x05\x30-100\"f\n\x1b\x41ssertionConsumerServiceURL\x12\x1b\n\x03url\x18\x01 \x01(\tB\x0e\xe8\xc7\x31\x01\x8a\xc8\x31\x06<=8000\x12*\n\x05index\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\"\xb1\x02\n\x16SingleLogoutServiceURL\x12\x1b\n\x03url\x18\x01 \x01(\tB\x0e\xe8\xc7\x31\x01\x8a\xc8\x31\x06<=8000\x12 \n\x0cresponse_url\x18\x02 \x01(\tB\n\x8a\xc8\x31\x06<=8000\x12\x80\x01\n\x10protocol_binding\x18\x03 \x01(\x0e\x32`.yandex.cloud.organizationmanager.v1.idp.application.saml.SingleLogoutServiceURL.ProtocolBindingB\x04\xe8\xc7\x31\x01\"U\n\x0fProtocolBinding\x12 \n\x1cPROTOCOL_BINDING_UNSPECIFIED\x10\x00\x12\r\n\tHTTP_POST\x10\x01\x12\x11\n\rHTTP_REDIRECT\x10\x02\"\x92\x02\n\x10SecuritySettings\x12p\n\x0esignature_mode\x18\x01 \x01(\x0e\x32X.yandex.cloud.organizationmanager.v1.idp.application.saml.SecuritySettings.SignatureMode\x12 \n\x18signature_certificate_id\x18\x02 \x01(\t\"j\n\rSignatureMode\x12\x1e\n\x1aSIGNATURE_MODE_UNSPECIFIED\x10\x00\x12\x0e\n\nASSERTIONS\x10\x01\x12\x0c\n\x08RESPONSE\x10\x02\x12\x1b\n\x17RESPONSE_AND_ASSERTIONS\x10\x03\"\xce\x01\n\x10\x41ttributeMapping\x12W\n\x07name_id\x18\x01 \x01(\x0b\x32@.yandex.cloud.organizationmanager.v1.idp.application.saml.NameIdB\x04\xe8\xc7\x31\x01\x12\x61\n\nattributes\x18\x02 \x03(\x0b\x32\x43.yandex.cloud.organizationmanager.v1.idp.application.saml.AttributeB\x08\x82\xc8\x31\x04<=50\"\xb9\x01\n\x06NameId\x12]\n\x06\x66ormat\x18\x01 \x01(\x0e\x32G.yandex.cloud.organizationmanager.v1.idp.application.saml.NameId.FormatB\x04\xe8\xc7\x31\x01\x12\x13\n\x05value\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\";\n\x06\x46ormat\x12\x16\n\x12\x46ORMAT_UNSPECIFIED\x10\x00\x12\x0e\n\nPERSISTENT\x10\x01\x12\t\n\x05\x45MAIL\x10\x02\"F\n\tAttribute\x12\x1c\n\x04name\x18\x01 \x01(\tB\x0e\xe8\xc7\x31\x01\x8a\xc8\x31\x06<=8000\x12\x1b\n\x05value\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\xb1\x01\n\x13GroupClaimsSettings\x12p\n\x17group_distribution_type\x18\x01 \x01(\x0e\x32O.yandex.cloud.organizationmanager.v1.idp.application.saml.GroupDistributionType\x12(\n\x14group_attribute_name\x18\x02 \x01(\tB\n\x8a\xc8\x31\x06<=8000*o\n\x15GroupDistributionType\x12\'\n#GROUP_DISTRIBUTION_TYPE_UNSPECIFIED\x10\x00\x12\x08\n\x04NONE\x10\x01\x12\x13\n\x0f\x41SSIGNED_GROUPS\x10\x02\x12\x0e\n\nALL_GROUPS\x10\x03\x42\xa1\x01\n<yandex.cloud.api.organizationmanager.v1.idp.application.samlZagithub.com/yandex-cloud/go-genproto/yandex/cloud/organizationmanager/v1/idp/application/saml;samlb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.organizationmanager.v1.idp.application.saml.application_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n<yandex.cloud.api.organizationmanager.v1.idp.application.samlZagithub.com/yandex-cloud/go-genproto/yandex/cloud/organizationmanager/v1/idp/application/saml;saml'
  _globals['_APPLICATION_LABELSENTRY']._loaded_options = None
  _globals['_APPLICATION_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_SERVICEPROVIDER'].fields_by_name['entity_id']._loaded_options = None
  _globals['_SERVICEPROVIDER'].fields_by_name['entity_id']._serialized_options = b'\350\3071\001\212\3101\006<=8000'
  _globals['_SERVICEPROVIDER'].fields_by_name['acs_urls']._loaded_options = None
  _globals['_SERVICEPROVIDER'].fields_by_name['acs_urls']._serialized_options = b'\202\3101\0051-100'
  _globals['_SERVICEPROVIDER'].fields_by_name['slo_urls']._loaded_options = None
  _globals['_SERVICEPROVIDER'].fields_by_name['slo_urls']._serialized_options = b'\202\3101\0050-100'
  _globals['_ASSERTIONCONSUMERSERVICEURL'].fields_by_name['url']._loaded_options = None
  _globals['_ASSERTIONCONSUMERSERVICEURL'].fields_by_name['url']._serialized_options = b'\350\3071\001\212\3101\006<=8000'
  _globals['_SINGLELOGOUTSERVICEURL'].fields_by_name['url']._loaded_options = None
  _globals['_SINGLELOGOUTSERVICEURL'].fields_by_name['url']._serialized_options = b'\350\3071\001\212\3101\006<=8000'
  _globals['_SINGLELOGOUTSERVICEURL'].fields_by_name['response_url']._loaded_options = None
  _globals['_SINGLELOGOUTSERVICEURL'].fields_by_name['response_url']._serialized_options = b'\212\3101\006<=8000'
  _globals['_SINGLELOGOUTSERVICEURL'].fields_by_name['protocol_binding']._loaded_options = None
  _globals['_SINGLELOGOUTSERVICEURL'].fields_by_name['protocol_binding']._serialized_options = b'\350\3071\001'
  _globals['_ATTRIBUTEMAPPING'].fields_by_name['name_id']._loaded_options = None
  _globals['_ATTRIBUTEMAPPING'].fields_by_name['name_id']._serialized_options = b'\350\3071\001'
  _globals['_ATTRIBUTEMAPPING'].fields_by_name['attributes']._loaded_options = None
  _globals['_ATTRIBUTEMAPPING'].fields_by_name['attributes']._serialized_options = b'\202\3101\004<=50'
  _globals['_NAMEID'].fields_by_name['format']._loaded_options = None
  _globals['_NAMEID'].fields_by_name['format']._serialized_options = b'\350\3071\001'
  _globals['_NAMEID'].fields_by_name['value']._loaded_options = None
  _globals['_NAMEID'].fields_by_name['value']._serialized_options = b'\350\3071\001'
  _globals['_ATTRIBUTE'].fields_by_name['name']._loaded_options = None
  _globals['_ATTRIBUTE'].fields_by_name['name']._serialized_options = b'\350\3071\001\212\3101\006<=8000'
  _globals['_ATTRIBUTE'].fields_by_name['value']._loaded_options = None
  _globals['_ATTRIBUTE'].fields_by_name['value']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_GROUPCLAIMSSETTINGS'].fields_by_name['group_attribute_name']._loaded_options = None
  _globals['_GROUPCLAIMSSETTINGS'].fields_by_name['group_attribute_name']._serialized_options = b'\212\3101\006<=8000'
  _globals['_GROUPDISTRIBUTIONTYPE']._serialized_start=3002
  _globals['_GROUPDISTRIBUTIONTYPE']._serialized_end=3113
  _globals['_APPLICATION']._serialized_start=233
  _globals['_APPLICATION']._serialized_end=1280
  _globals['_APPLICATION_LABELSENTRY']._serialized_start=1146
  _globals['_APPLICATION_LABELSENTRY']._serialized_end=1191
  _globals['_APPLICATION_STATUS']._serialized_start=1193
  _globals['_APPLICATION_STATUS']._serialized_end=1280
  _globals['_IDENTITYPROVIDERMETADATA']._serialized_start=1282
  _globals['_IDENTITYPROVIDERMETADATA']._serialized_end=1380
  _globals['_SERVICEPROVIDER']._serialized_start=1383
  _globals['_SERVICEPROVIDER']._serialized_end=1662
  _globals['_ASSERTIONCONSUMERSERVICEURL']._serialized_start=1664
  _globals['_ASSERTIONCONSUMERSERVICEURL']._serialized_end=1766
  _globals['_SINGLELOGOUTSERVICEURL']._serialized_start=1769
  _globals['_SINGLELOGOUTSERVICEURL']._serialized_end=2074
  _globals['_SINGLELOGOUTSERVICEURL_PROTOCOLBINDING']._serialized_start=1989
  _globals['_SINGLELOGOUTSERVICEURL_PROTOCOLBINDING']._serialized_end=2074
  _globals['_SECURITYSETTINGS']._serialized_start=2077
  _globals['_SECURITYSETTINGS']._serialized_end=2351
  _globals['_SECURITYSETTINGS_SIGNATUREMODE']._serialized_start=2245
  _globals['_SECURITYSETTINGS_SIGNATUREMODE']._serialized_end=2351
  _globals['_ATTRIBUTEMAPPING']._serialized_start=2354
  _globals['_ATTRIBUTEMAPPING']._serialized_end=2560
  _globals['_NAMEID']._serialized_start=2563
  _globals['_NAMEID']._serialized_end=2748
  _globals['_NAMEID_FORMAT']._serialized_start=2689
  _globals['_NAMEID_FORMAT']._serialized_end=2748
  _globals['_ATTRIBUTE']._serialized_start=2750
  _globals['_ATTRIBUTE']._serialized_end=2820
  _globals['_GROUPCLAIMSSETTINGS']._serialized_start=2823
  _globals['_GROUPCLAIMSSETTINGS']._serialized_end=3000
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _DeletionProtectionMode:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _DeletionProtectionModeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_DeletionProtectionMode.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    DELETION_PROTECTION_MODE_UNSPECIFIED: _DeletionProtectionMode.ValueType  # 0
    DELETION_PROTECTION_MODE_DISABLED: _DeletionProtectionMode.ValueType  # 1
    """Deletion protection is disabled"""
    DELETION_PROTECTION_MODE_ENABLED: _DeletionProtectionMode.ValueType  # 2
    """Deletion protection is enabled"""
    DELETION_PROTECTION_MODE_INHERITED: _DeletionProtectionMode.ValueType  # 3
    """Deletion protection mode is inherited from the cluster"""

class DeletionProtectionMode(_DeletionProtectionMode, metaclass=_DeletionProtectionModeEnumTypeWrapper): ...

DELETION_PROTECTION_MODE_UNSPECIFIED: DeletionProtectionMode.ValueType  # 0
DELETION_PROTECTION_MODE_DISABLED: DeletionProtectionMode.ValueType  # 1
"""Deletion protection is disabled"""
DELETION_PROTECTION_MODE_ENABLED: DeletionProtectionMode.ValueType  # 2
"""Deletion protection is enabled"""
DELETION_PROTECTION_MODE_INHERITED: DeletionProtectionMode.ValueType  # 3
"""Deletion protection mode is inherited from the cluster"""
global___DeletionProtectionMode = DeletionProtectionMode



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing
import yandex.cloud.logging.v1.log_entry_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _HttpMethod:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _HttpMethodEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_HttpMethod.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    HTTP_METHOD_UNSPECIFIED: _HttpMethod.ValueType  # 0
    OPTIONS: _HttpMethod.ValueType  # 1
    """OPTIONS HTTP method."""
    GET: _HttpMethod.ValueType  # 2
    """GET HTTP method."""
    HEAD: _HttpMethod.ValueType  # 3
    """HEAD HTTP method."""
    POST: _HttpMethod.ValueType  # 4
    """POST HTTP method."""
    PUT: _HttpMethod.ValueType  # 5
    """PUT HTTP method."""
    PATCH: _HttpMethod.ValueType  # 6
    """PATCH HTTP method."""
    DELETE: _HttpMethod.ValueType  # 7
    """DELETE HTTP method."""
    TRACE: _HttpMethod.ValueType  # 8
    """TRACE HTTP method."""
    CONNECT: _HttpMethod.ValueType  # 9
    """CONNECT HTTP method."""

class HttpMethod(_HttpMethod, metaclass=_HttpMethodEnumTypeWrapper): ...

HTTP_METHOD_UNSPECIFIED: HttpMethod.ValueType  # 0
OPTIONS: HttpMethod.ValueType  # 1
"""OPTIONS HTTP method."""
GET: HttpMethod.ValueType  # 2
"""GET HTTP method."""
HEAD: HttpMethod.ValueType  # 3
"""HEAD HTTP method."""
POST: HttpMethod.ValueType  # 4
"""POST HTTP method."""
PUT: HttpMethod.ValueType  # 5
"""PUT HTTP method."""
PATCH: HttpMethod.ValueType  # 6
"""PATCH HTTP method."""
DELETE: HttpMethod.ValueType  # 7
"""DELETE HTTP method."""
TRACE: HttpMethod.ValueType  # 8
"""TRACE HTTP method."""
CONNECT: HttpMethod.ValueType  # 9
"""CONNECT HTTP method."""
global___HttpMethod = HttpMethod

@typing.final
class McpGateway(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[McpGateway._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNSPECIFIED: McpGateway._Status.ValueType  # 0
        CREATING: McpGateway._Status.ValueType  # 1
        """MCP Gateway is being created."""
        ACTIVE: McpGateway._Status.ValueType  # 2
        """MCP Gateway is ready to use."""
        UPDATING: McpGateway._Status.ValueType  # 3
        """MCP Gateway is being updated."""
        DELETING: McpGateway._Status.ValueType  # 4
        """MCP Gateway is being deleted."""
        ERROR: McpGateway._Status.ValueType  # 5
        """MCP Gateway is in an error state. The only allowed action is delete."""

    class Status(_Status, metaclass=_StatusEnumTypeWrapper): ...
    STATUS_UNSPECIFIED: McpGateway.Status.ValueType  # 0
    CREATING: McpGateway.Status.ValueType  # 1
    """MCP Gateway is being created."""
    ACTIVE: McpGateway.Status.ValueType  # 2
    """MCP Gateway is ready to use."""
    UPDATING: McpGateway.Status.ValueType  # 3
    """MCP Gateway is being updated."""
    DELETING: McpGateway.Status.ValueType  # 4
    """MCP Gateway is being deleted."""
    ERROR: McpGateway.Status.ValueType  # 5
    """MCP Gateway is in an error state. The only allowed action is delete."""

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    TOOLS_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    BASE_DOMAIN_FIELD_NUMBER: builtins.int
    LOG_OPTIONS_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    NETWORK_ID_FIELD_NUMBER: builtins.int
    CLOUD_ID_FIELD_NUMBER: builtins.int
    PUBLIC_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the MCP Gateway. Generated at creation time."""
    folder_id: builtins.str
    """ID of the folder that the MCP Gateway belongs to."""
    name: builtins.str
    """Name of the MCP Gateway."""
    description: builtins.str
    """Description of the MCP Gateway."""
    status: global___McpGateway.Status.ValueType
    """Status of the MCP Gateway."""
    base_domain: builtins.str
    """Base domain of the MCP Gateway."""
    service_account_id: builtins.str
    """ID of the Service Account which will be used for resource access in MCP Gateway call."""
    network_id: builtins.str
    """ID of the VPC network MCP Gateway will be executed in, in order to access private resources."""
    cloud_id: builtins.str
    """ID of the cloud that the MCP Gateway belongs to."""
    public: builtins.bool
    """Publicity of the MCP Gateway. Public MCP Gateway can be accessed by anybody."""
    @property
    def tools(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___McpTool]:
        """Tools of the MCP Gateway."""

    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp for the MCP Gateway."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """MCP Gateway labels as `key:value` pairs."""

    @property
    def log_options(self) -> global___LogOptions:
        """Log options for the MCP Gateway."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        folder_id: builtins.str = ...,
        tools: collections.abc.Iterable[global___McpTool] | None = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        status: global___McpGateway.Status.ValueType = ...,
        base_domain: builtins.str = ...,
        log_options: global___LogOptions | None = ...,
        service_account_id: builtins.str = ...,
        network_id: builtins.str = ...,
        cloud_id: builtins.str = ...,
        public: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at", "log_options", b"log_options"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["base_domain", b"base_domain", "cloud_id", b"cloud_id", "created_at", b"created_at", "description", b"description", "folder_id", b"folder_id", "id", b"id", "labels", b"labels", "log_options", b"log_options", "name", b"name", "network_id", b"network_id", "public", b"public", "service_account_id", b"service_account_id", "status", b"status", "tools", b"tools"]) -> None: ...

global___McpGateway = McpGateway

@typing.final
class McpGatewayPreview(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    BASE_DOMAIN_FIELD_NUMBER: builtins.int
    LOG_OPTIONS_FIELD_NUMBER: builtins.int
    NETWORK_ID_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    PUBLIC_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the MCP Gateway. Generated at creation time."""
    folder_id: builtins.str
    """ID of the folder that the MCP Gateway belongs to."""
    name: builtins.str
    """Name of the MCP Gateway."""
    description: builtins.str
    """Description of the MCP Gateway."""
    status: global___McpGateway.Status.ValueType
    """Status of the MCP Gateway."""
    base_domain: builtins.str
    """Base domain of the MCP Gateway."""
    network_id: builtins.str
    """ID of the VPC network MCP Gateway will be executed in, in order to access private resources."""
    service_account_id: builtins.str
    """ID of the Service Account which will be used for resource access in MCP Gateway call."""
    public: builtins.bool
    """Publicity of the MCP Gateway. Public MCP Gateway can be accessed by anybody."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp for the MCP Gateway."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """MCP Gateway labels as `key:value` pairs."""

    @property
    def log_options(self) -> global___LogOptions:
        """Log options for the MCP Gateway."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        folder_id: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        status: global___McpGateway.Status.ValueType = ...,
        base_domain: builtins.str = ...,
        log_options: global___LogOptions | None = ...,
        network_id: builtins.str = ...,
        service_account_id: builtins.str = ...,
        public: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at", "log_options", b"log_options"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["base_domain", b"base_domain", "created_at", b"created_at", "description", b"description", "folder_id", b"folder_id", "id", b"id", "labels", b"labels", "log_options", b"log_options", "name", b"name", "network_id", b"network_id", "public", b"public", "service_account_id", b"service_account_id", "status", b"status"]) -> None: ...

global___McpGatewayPreview = McpGatewayPreview

@typing.final
class LogOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISABLED_FIELD_NUMBER: builtins.int
    LOG_GROUP_ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    MIN_LEVEL_FIELD_NUMBER: builtins.int
    disabled: builtins.bool
    """Is logging from MCP Gateway disabled."""
    log_group_id: builtins.str
    """ID of the logging group which should be used for MCP Gateway logs."""
    folder_id: builtins.str
    """ID of the folder which default logging group should be used for MCP Gateway logs."""
    min_level: yandex.cloud.logging.v1.log_entry_pb2.LogLevel.Level.ValueType
    """Minimum logs level.

    See [LogLevel.Level] for details.
    """
    def __init__(
        self,
        *,
        disabled: builtins.bool = ...,
        log_group_id: builtins.str = ...,
        folder_id: builtins.str = ...,
        min_level: yandex.cloud.logging.v1.log_entry_pb2.LogLevel.Level.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["destination", b"destination", "folder_id", b"folder_id", "log_group_id", b"log_group_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["destination", b"destination", "disabled", b"disabled", "folder_id", b"folder_id", "log_group_id", b"log_group_id", "min_level", b"min_level"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["destination", b"destination"]) -> typing.Literal["log_group_id", "folder_id"] | None: ...

global___LogOptions = LogOptions

@typing.final
class McpTool(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    INPUT_JSON_SCHEMA_FIELD_NUMBER: builtins.int
    ACTION_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the tool."""
    description: builtins.str
    """Description of the tool."""
    input_json_schema: builtins.str
    """JSON Schema describing tool input."""
    @property
    def action(self) -> global___McpToolAction:
        """Action to perform when this tool is invoked."""

    def __init__(
        self,
        *,
        name: builtins.str = ...,
        description: builtins.str = ...,
        input_json_schema: builtins.str = ...,
        action: global___McpToolAction | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["action", b"action"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["action", b"action", "description", b"description", "input_json_schema", b"input_json_schema", "name", b"name"]) -> None: ...

global___McpTool = McpTool

@typing.final
class McpToolAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FUNCTION_CALL_FIELD_NUMBER: builtins.int
    CONTAINER_CALL_FIELD_NUMBER: builtins.int
    HTTP_CALL_FIELD_NUMBER: builtins.int
    MCP_CALL_FIELD_NUMBER: builtins.int
    GRPC_CALL_FIELD_NUMBER: builtins.int
    START_WORKFLOW_FIELD_NUMBER: builtins.int
    @property
    def function_call(self) -> global___FunctionCall:
        """Call Serverless Function."""

    @property
    def container_call(self) -> global___ContainerCall:
        """Call Serverless Container."""

    @property
    def http_call(self) -> global___HttpCall:
        """Send HTTP request."""

    @property
    def mcp_call(self) -> global___McpCall:
        """Call MCP Gateway."""

    @property
    def grpc_call(self) -> global___GrpcCall:
        """Call gRPC endpoint. Server must support gRPC reflection."""

    @property
    def start_workflow(self) -> global___StartWorkflow:
        """Start Workflow."""

    def __init__(
        self,
        *,
        function_call: global___FunctionCall | None = ...,
        container_call: global___ContainerCall | None = ...,
        http_call: global___HttpCall | None = ...,
        mcp_call: global___McpCall | None = ...,
        grpc_call: global___GrpcCall | None = ...,
        start_workflow: global___StartWorkflow | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["action", b"action", "container_call", b"container_call", "function_call", b"function_call", "grpc_call", b"grpc_call", "http_call", b"http_call", "mcp_call", b"mcp_call", "start_workflow", b"start_workflow"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["action", b"action", "container_call", b"container_call", "function_call", b"function_call", "grpc_call", b"grpc_call", "http_call", b"http_call", "mcp_call", b"mcp_call", "start_workflow", b"start_workflow"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["action", b"action"]) -> typing.Literal["function_call", "container_call", "http_call", "mcp_call", "grpc_call", "start_workflow"] | None: ...

global___McpToolAction = McpToolAction

@typing.final
class FunctionCall(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FUNCTION_ID_FIELD_NUMBER: builtins.int
    TAG_FIELD_NUMBER: builtins.int
    function_id: builtins.str
    """ID of serverless function to call."""
    tag: builtins.str
    """Tag of serverless function. If empty, $latest tag will be used."""
    def __init__(
        self,
        *,
        function_id: builtins.str = ...,
        tag: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["function_id", b"function_id", "tag", b"tag"]) -> None: ...

global___FunctionCall = FunctionCall

@typing.final
class ContainerCall(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class HeadersEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing.final
    class QueryEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    CONTAINER_ID_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    METHOD_FIELD_NUMBER: builtins.int
    BODY_FIELD_NUMBER: builtins.int
    HEADERS_FIELD_NUMBER: builtins.int
    QUERY_FIELD_NUMBER: builtins.int
    FORWARD_HEADERS_FIELD_NUMBER: builtins.int
    container_id: builtins.str
    """ID of serverless container to call."""
    path: builtins.str
    """Relative request path inside the container."""
    method: global___HttpMethod.ValueType
    """HTTP method to use for the request."""
    body: builtins.str
    """Request body to send to the container."""
    @property
    def headers(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """HTTP headers to include in the request."""

    @property
    def query(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Query string parameters to include in the request."""

    @property
    def forward_headers(self) -> global___ForwardHeadersPolicy:
        """Policy that defines which headers from the incoming request should be forwarded"""

    def __init__(
        self,
        *,
        container_id: builtins.str = ...,
        path: builtins.str = ...,
        method: global___HttpMethod.ValueType = ...,
        body: builtins.str = ...,
        headers: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        query: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        forward_headers: global___ForwardHeadersPolicy | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["forward_headers", b"forward_headers"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["body", b"body", "container_id", b"container_id", "forward_headers", b"forward_headers", "headers", b"headers", "method", b"method", "path", b"path", "query", b"query"]) -> None: ...

global___ContainerCall = ContainerCall

@typing.final
class HttpCall(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class HeadersEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing.final
    class QueryEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    URL_FIELD_NUMBER: builtins.int
    METHOD_FIELD_NUMBER: builtins.int
    BODY_FIELD_NUMBER: builtins.int
    HEADERS_FIELD_NUMBER: builtins.int
    QUERY_FIELD_NUMBER: builtins.int
    USE_SERVICE_ACCOUNT_FIELD_NUMBER: builtins.int
    FORWARD_HEADERS_FIELD_NUMBER: builtins.int
    url: builtins.str
    """Absolute URL to send the request to. (required)"""
    method: global___HttpMethod.ValueType
    """HTTP method to use."""
    body: builtins.str
    """Request body payload."""
    use_service_account: builtins.bool
    """Use MCP Gateway service account credentials for the request."""
    @property
    def headers(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """HTTP headers to include."""

    @property
    def query(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Query string parameters to include."""

    @property
    def forward_headers(self) -> global___ForwardHeadersPolicy:
        """Policy that defines which headers from the incoming request should be forwarded"""

    def __init__(
        self,
        *,
        url: builtins.str = ...,
        method: global___HttpMethod.ValueType = ...,
        body: builtins.str = ...,
        headers: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        query: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        use_service_account: builtins.bool = ...,
        forward_headers: global___ForwardHeadersPolicy | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["forward_headers", b"forward_headers"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["body", b"body", "forward_headers", b"forward_headers", "headers", b"headers", "method", b"method", "query", b"query", "url", b"url", "use_service_account", b"use_service_account"]) -> None: ...

global___HttpCall = HttpCall

@typing.final
class ForwardHeadersPolicy(google.protobuf.message.Message):
    """Policy defining which HTTP headers from the incoming request should be forwarded."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _ForwardMode:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ForwardModeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ForwardHeadersPolicy._ForwardMode.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        FORWARD_MODE_UNSPECIFIED: ForwardHeadersPolicy._ForwardMode.ValueType  # 0
        WHITE_LIST: ForwardHeadersPolicy._ForwardMode.ValueType  # 1
        """Whitelist mode: only headers listed in the headers field will be forwarded.
        All other headers from the incoming request will be excluded.
        """
        BLACK_LIST: ForwardHeadersPolicy._ForwardMode.ValueType  # 2
        """Blacklist mode: all headers from the incoming request will be forwarded
        except those listed in the headers field.
        """

    class ForwardMode(_ForwardMode, metaclass=_ForwardModeEnumTypeWrapper):
        """Mode for header forwarding policy."""

    FORWARD_MODE_UNSPECIFIED: ForwardHeadersPolicy.ForwardMode.ValueType  # 0
    WHITE_LIST: ForwardHeadersPolicy.ForwardMode.ValueType  # 1
    """Whitelist mode: only headers listed in the headers field will be forwarded.
    All other headers from the incoming request will be excluded.
    """
    BLACK_LIST: ForwardHeadersPolicy.ForwardMode.ValueType  # 2
    """Blacklist mode: all headers from the incoming request will be forwarded
    except those listed in the headers field.
    """

    MODE_FIELD_NUMBER: builtins.int
    HEADERS_FIELD_NUMBER: builtins.int
    mode: global___ForwardHeadersPolicy.ForwardMode.ValueType
    """Mode of header forwarding. Determines how the headers list is interpreted."""
    @property
    def headers(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of HTTP header names to forward. Interpretation depends on the mode:
        - WHITE_LIST: only these headers will be forwarded (all others are excluded)
        - BLACK_LIST: all headers except these will be forwarded (these are excluded)
        """

    def __init__(
        self,
        *,
        mode: global___ForwardHeadersPolicy.ForwardMode.ValueType = ...,
        headers: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["headers", b"headers", "mode", b"mode"]) -> None: ...

global___ForwardHeadersPolicy = ForwardHeadersPolicy

@typing.final
class McpCall(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Transport:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _TransportEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[McpCall._Transport.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        TRANSPORT_UNSPECIFIED: McpCall._Transport.ValueType  # 0
        """Unspecified transport."""
        SSE: McpCall._Transport.ValueType  # 1
        """Server-Sent Events (HTTP SSE)."""
        STREAMABLE: McpCall._Transport.ValueType  # 2
        """Streamable HTTP transport."""

    class Transport(_Transport, metaclass=_TransportEnumTypeWrapper): ...
    TRANSPORT_UNSPECIFIED: McpCall.Transport.ValueType  # 0
    """Unspecified transport."""
    SSE: McpCall.Transport.ValueType  # 1
    """Server-Sent Events (HTTP SSE)."""
    STREAMABLE: McpCall.Transport.ValueType  # 2
    """Streamable HTTP transport."""

    @typing.final
    class ForwardHeadersEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing.final
    class NoAuthorization(google.protobuf.message.Message):
        """No authorization will be sent."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        def __init__(
            self,
        ) -> None: ...

    @typing.final
    class SaAuthorization(google.protobuf.message.Message):
        """Use MCP Gateway service account to authorize."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        def __init__(
            self,
        ) -> None: ...

    @typing.final
    class HeaderAuthorization(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        HEADER_NAME_FIELD_NUMBER: builtins.int
        HEADER_VALUE_FIELD_NUMBER: builtins.int
        header_name: builtins.str
        """Name of the authorization header to send."""
        header_value: builtins.str
        """Value of the authorization header to send."""
        def __init__(
            self,
            *,
            header_name: builtins.str = ...,
            header_value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["header_name", b"header_name", "header_value", b"header_value"]) -> None: ...

    @typing.final
    class ToolCall(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        TOOL_NAME_FIELD_NUMBER: builtins.int
        PARAMETERS_JSON_FIELD_NUMBER: builtins.int
        tool_name: builtins.str
        """Name of the tool to invoke on the MCP endpoint. (required)"""
        parameters_json: builtins.str
        """JSON-encoded parameters to pass to the tool."""
        def __init__(
            self,
            *,
            tool_name: builtins.str = ...,
            parameters_json: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["parameters_json", b"parameters_json", "tool_name", b"tool_name"]) -> None: ...

    URL_FIELD_NUMBER: builtins.int
    TOOL_CALL_FIELD_NUMBER: builtins.int
    TRANSPORT_FIELD_NUMBER: builtins.int
    UNAUTHORIZED_FIELD_NUMBER: builtins.int
    HEADER_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_FIELD_NUMBER: builtins.int
    FORWARD_HEADERS_FIELD_NUMBER: builtins.int
    TRANSFER_HEADERS_FIELD_NUMBER: builtins.int
    url: builtins.str
    """MCP endpoint base URL. (required)"""
    transport: global___McpCall.Transport.ValueType
    """Transport to use for MCP communication."""
    @property
    def tool_call(self) -> global___McpCall.ToolCall:
        """Tool call action to invoke a specific tool on the MCP endpoint."""

    @property
    def unauthorized(self) -> global___McpCall.NoAuthorization:
        """No authorization mode."""

    @property
    def header(self) -> global___McpCall.HeaderAuthorization:
        """Header-based authorization."""

    @property
    def service_account(self) -> global___McpCall.SaAuthorization:
        """Service account authorization."""

    @property
    def forward_headers(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Headers from the incoming request to forward downstream by name."""

    @property
    def transfer_headers(self) -> global___ForwardHeadersPolicy:
        """Policy that defines which headers from the incoming request should be forwarded to the HTTP endpoint"""

    def __init__(
        self,
        *,
        url: builtins.str = ...,
        tool_call: global___McpCall.ToolCall | None = ...,
        transport: global___McpCall.Transport.ValueType = ...,
        unauthorized: global___McpCall.NoAuthorization | None = ...,
        header: global___McpCall.HeaderAuthorization | None = ...,
        service_account: global___McpCall.SaAuthorization | None = ...,
        forward_headers: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        transfer_headers: global___ForwardHeadersPolicy | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["action", b"action", "authorization", b"authorization", "header", b"header", "service_account", b"service_account", "tool_call", b"tool_call", "transfer_headers", b"transfer_headers", "unauthorized", b"unauthorized"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["action", b"action", "authorization", b"authorization", "forward_headers", b"forward_headers", "header", b"header", "service_account", b"service_account", "tool_call", b"tool_call", "transfer_headers", b"transfer_headers", "transport", b"transport", "unauthorized", b"unauthorized", "url", b"url"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["action", b"action"]) -> typing.Literal["tool_call"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["authorization", b"authorization"]) -> typing.Literal["unauthorized", "header", "service_account"] | None: ...

global___McpCall = McpCall

@typing.final
class GrpcCall(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class HeadersEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ENDPOINT_FIELD_NUMBER: builtins.int
    METHOD_FIELD_NUMBER: builtins.int
    USE_SERVICE_ACCOUNT_FIELD_NUMBER: builtins.int
    BODY_FIELD_NUMBER: builtins.int
    HEADERS_FIELD_NUMBER: builtins.int
    FORWARD_HEADERS_FIELD_NUMBER: builtins.int
    endpoint: builtins.str
    """gRPC server endpoint, e.g., host:port. (required)"""
    method: builtins.str
    """Fully qualified gRPC method name, e.g., package.Service/Method. (required)"""
    use_service_account: builtins.bool
    """Use MCP Gateway service account for authentication."""
    body: builtins.str
    """Request body payload for the call."""
    @property
    def headers(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """gRPC/HTTP headers to include with the call."""

    @property
    def forward_headers(self) -> global___ForwardHeadersPolicy:
        """Policy that defines which headers from the incoming request should be forwarded"""

    def __init__(
        self,
        *,
        endpoint: builtins.str = ...,
        method: builtins.str = ...,
        use_service_account: builtins.bool = ...,
        body: builtins.str = ...,
        headers: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        forward_headers: global___ForwardHeadersPolicy | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["forward_headers", b"forward_headers"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["body", b"body", "endpoint", b"endpoint", "forward_headers", b"forward_headers", "headers", b"headers", "method", b"method", "use_service_account", b"use_service_account"]) -> None: ...

global___GrpcCall = GrpcCall

@typing.final
class StartWorkflow(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Mode:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ModeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[StartWorkflow._Mode.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        MODE_UNSPECIFIED: StartWorkflow._Mode.ValueType  # 0
        """Unspecified mode. When not set, defaults to SYNC behavior."""
        SYNC: StartWorkflow._Mode.ValueType  # 1
        """Synchronous mode. The call blocks until the workflow execution completes."""
        ASYNC: StartWorkflow._Mode.ValueType  # 2
        """Asynchronous mode. The call returns immediately after starting the workflow.
        Returns the execution ID for tracking the workflow progress separately.
        """

    class Mode(_Mode, metaclass=_ModeEnumTypeWrapper): ...
    MODE_UNSPECIFIED: StartWorkflow.Mode.ValueType  # 0
    """Unspecified mode. When not set, defaults to SYNC behavior."""
    SYNC: StartWorkflow.Mode.ValueType  # 1
    """Synchronous mode. The call blocks until the workflow execution completes."""
    ASYNC: StartWorkflow.Mode.ValueType  # 2
    """Asynchronous mode. The call returns immediately after starting the workflow.
    Returns the execution ID for tracking the workflow progress separately.
    """

    WORKFLOW_ID_FIELD_NUMBER: builtins.int
    INPUT_JSON_FIELD_NUMBER: builtins.int
    MODE_FIELD_NUMBER: builtins.int
    workflow_id: builtins.str
    """ID of the Workflow to start. (required)"""
    input_json: builtins.str
    """JSON-encoded workflow input payload."""
    mode: global___StartWorkflow.Mode.ValueType
    """Execution mode for the workflow.
    Determines whether the call should wait for workflow completion (SYNC)
    or return immediately after starting the workflow (ASYNC).
    """
    def __init__(
        self,
        *,
        workflow_id: builtins.str = ...,
        input_json: builtins.str = ...,
        mode: global___StartWorkflow.Mode.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["input_json", b"input_json", "mode", b"mode", "workflow_id", b"workflow_id"]) -> None: ...

global___StartWorkflow = StartWorkflow



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.devtools.ycvc.v1.control_service_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class VersionControlServiceStub:
    """Version Control Service for managing tool version blacklists.
    This service manages obsolete (deprecated/blocked) versions only.

    API Behavior:
    - Supported versions: Return successful InitResponse.
    - Deprecated versions: Return successful InitResponse with deprecation_warning.
    - Blocked versions: Return FAILED_PRECONDITION error with descriptive message.
    """

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Init: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.devtools.ycvc.v1.control_service_pb2.InitRequest,
        yandex.cloud.devtools.ycvc.v1.control_service_pb2.InitResponse,
    ]
    """Initializes client and checks if the provided version is obsolete.
    Returns FAILED_PRECONDITION error for blocked versions.
    """

class VersionControlServiceAsyncStub:
    """Version Control Service for managing tool version blacklists.
    This service manages obsolete (deprecated/blocked) versions only.

    API Behavior:
    - Supported versions: Return successful InitResponse.
    - Deprecated versions: Return successful InitResponse with deprecation_warning.
    - Blocked versions: Return FAILED_PRECONDITION error with descriptive message.
    """

    Init: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.devtools.ycvc.v1.control_service_pb2.InitRequest,
        yandex.cloud.devtools.ycvc.v1.control_service_pb2.InitResponse,
    ]
    """Initializes client and checks if the provided version is obsolete.
    Returns FAILED_PRECONDITION error for blocked versions.
    """

class VersionControlServiceServicer(metaclass=abc.ABCMeta):
    """Version Control Service for managing tool version blacklists.
    This service manages obsolete (deprecated/blocked) versions only.

    API Behavior:
    - Supported versions: Return successful InitResponse.
    - Deprecated versions: Return successful InitResponse with deprecation_warning.
    - Blocked versions: Return FAILED_PRECONDITION error with descriptive message.
    """

    @abc.abstractmethod
    def Init(
        self,
        request: yandex.cloud.devtools.ycvc.v1.control_service_pb2.InitRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.devtools.ycvc.v1.control_service_pb2.InitResponse, collections.abc.Awaitable[yandex.cloud.devtools.ycvc.v1.control_service_pb2.InitResponse]]:
        """Initializes client and checks if the provided version is obsolete.
        Returns FAILED_PRECONDITION error for blocked versions.
        """

def add_VersionControlServiceServicer_to_server(servicer: VersionControlServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/billing/usage_records/v1/credit.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/billing/usage_records/v1/credit.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.billing.usage_records.v1 import common_types_pb2 as yandex_dot_cloud_dot_billing_dot_usage__records_dot_v1_dot_common__types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2yandex/cloud/billing/usage_records/v1/credit.proto\x12%yandex.cloud.billing.usage_records.v1\x1a\x38yandex/cloud/billing/usage_records/v1/common_types.proto\"\x96\x03\n\rCreditDetails\x12\x44\n\x06\x63redit\x18\x01 \x01(\x0b\x32\x34.yandex.cloud.billing.usage_records.v1.StringDecimal\x12S\n\x15monetary_grant_credit\x18\x02 \x01(\x0b\x32\x34.yandex.cloud.billing.usage_records.v1.StringDecimal\x12U\n\x17volume_incentive_credit\x18\x03 \x01(\x0b\x32\x34.yandex.cloud.billing.usage_records.v1.StringDecimal\x12H\n\ncud_credit\x18\x04 \x01(\x0b\x32\x34.yandex.cloud.billing.usage_records.v1.StringDecimal\x12I\n\x0b\x66ree_credit\x18\x05 \x01(\x0b\x32\x34.yandex.cloud.billing.usage_records.v1.StringDecimalB\x83\x01\n)yandex.cloud.api.billing.usage_records.v1ZVgithub.com/yandex-cloud/go-genproto/yandex/cloud/billing/usage_records/v1;usageRecordsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.billing.usage_records.v1.credit_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n)yandex.cloud.api.billing.usage_records.v1ZVgithub.com/yandex-cloud/go-genproto/yandex/cloud/billing/usage_records/v1;usageRecords'
  _globals['_CREDITDETAILS']._serialized_start=152
  _globals['_CREDITDETAILS']._serialized_end=558
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.access.access_pb2
import yandex.cloud.operation.operation_pb2
import yandex.cloud.organizationmanager.v1.idp.application.oauth.application_pb2
import yandex.cloud.organizationmanager.v1.idp.application.oauth.application_service_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class ApplicationServiceStub:
    """A set of methods for managing OAuth application."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.application.oauth.application_service_pb2.GetApplicationRequest,
        yandex.cloud.organizationmanager.v1.idp.application.oauth.application_pb2.Application,
    ]
    """Returns the specified OAuth application resource.

    To get the list of available OAuth applications, make a [List] request.
    """

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.application.oauth.application_service_pb2.ListApplicationsRequest,
        yandex.cloud.organizationmanager.v1.idp.application.oauth.application_service_pb2.ListApplicationsResponse,
    ]
    """Retrieves the list of OAuth applications in the specified organization."""

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.application.oauth.application_service_pb2.CreateApplicationRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates an OAuth application in the specified organization."""

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.application.oauth.application_service_pb2.UpdateApplicationRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified OAuth application."""

    Suspend: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.application.oauth.application_service_pb2.SuspendApplicationRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Sets status to SUSPENDED for the specified OAuth application."""

    Reactivate: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.application.oauth.application_service_pb2.ReactivateApplicationRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Sets status to ACTIVE for the specified OAuth application."""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.application.oauth.application_service_pb2.DeleteApplicationRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified OAuth application."""

    ListOperations: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.application.oauth.application_service_pb2.ListApplicationOperationsRequest,
        yandex.cloud.organizationmanager.v1.idp.application.oauth.application_service_pb2.ListApplicationOperationsResponse,
    ]
    """Lists operations for the specified OAuth application."""

    ListAccessBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.ListAccessBindingsRequest,
        yandex.cloud.access.access_pb2.ListAccessBindingsResponse,
    ]
    """Lists access bindings for the specified OAuth application."""

    SetAccessBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.SetAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Sets access bindings for the specified OAuth application."""

    UpdateAccessBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.UpdateAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates access bindings for the specified OAuth application."""

    ListAssignments: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.application.oauth.application_service_pb2.ListAssignmentsRequest,
        yandex.cloud.organizationmanager.v1.idp.application.oauth.application_service_pb2.ListAssignmentsResponse,
    ]
    """Lists assignmnents for the specified OAuth application."""

    UpdateAssignments: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.application.oauth.application_service_pb2.UpdateAssignmentsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates assignmnents for the specified OAuth application."""

class ApplicationServiceAsyncStub:
    """A set of methods for managing OAuth application."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.application.oauth.application_service_pb2.GetApplicationRequest,
        yandex.cloud.organizationmanager.v1.idp.application.oauth.application_pb2.Application,
    ]
    """Returns the specified OAuth application resource.

    To get the list of available OAuth applications, make a [List] request.
    """

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.application.oauth.application_service_pb2.ListApplicationsRequest,
        yandex.cloud.organizationmanager.v1.idp.application.oauth.application_service_pb2.ListApplicationsResponse,
    ]
    """Retrieves the list of OAuth applications in the specified organization."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.application.oauth.application_service_pb2.CreateApplicationRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates an OAuth application in the specified organization."""

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.application.oauth.application_service_pb2.UpdateApplicationRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified OAuth application."""

    Suspend: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.application.oauth.application_service_pb2.SuspendApplicationRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Sets status to SUSPENDED for the specified OAuth application."""

    Reactivate: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.application.oauth.application_service_pb2.ReactivateApplicationRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Sets status to ACTIVE for the specified OAuth application."""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.application.oauth.application_service_pb2.DeleteApplicationRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified OAuth application."""

    ListOperations: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.application.oauth.application_service_pb2.ListApplicationOperationsRequest,
        yandex.cloud.organizationmanager.v1.idp.application.oauth.application_service_pb2.ListApplicationOperationsResponse,
    ]
    """Lists operations for the specified OAuth application."""

    ListAccessBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.ListAccessBindingsRequest,
        yandex.cloud.access.access_pb2.ListAccessBindingsResponse,
    ]
    """Lists access bindings for the specified OAuth application."""

    SetAccessBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.SetAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Sets access bindings for the specified OAuth application."""

    UpdateAccessBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.UpdateAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates access bindings for the specified OAuth application."""

    ListAssignments: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.application.oauth.application_service_pb2.ListAssignmentsRequest,
        yandex.cloud.organizationmanager.v1.idp.application.oauth.application_service_pb2.ListAssignmentsResponse,
    ]
    """Lists assignmnents for the specified OAuth application."""

    UpdateAssignments: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.idp.application.oauth.application_service_pb2.UpdateAssignmentsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates assignmnents for the specified OAuth application."""

class ApplicationServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing OAuth application."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.organizationmanager.v1.idp.application.oauth.application_service_pb2.GetApplicationRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.organizationmanager.v1.idp.application.oauth.application_pb2.Application, collections.abc.Awaitable[yandex.cloud.organizationmanager.v1.idp.application.oauth.application_pb2.Application]]:
        """Returns the specified OAuth application resource.

        To get the list of available OAuth applications, make a [List] request.
        """

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.organizationmanager.v1.idp.application.oauth.application_service_pb2.ListApplicationsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.organizationmanager.v1.idp.application.oauth.application_service_pb2.ListApplicationsResponse, collections.abc.Awaitable[yandex.cloud.organizationmanager.v1.idp.application.oauth.application_service_pb2.ListApplicationsResponse]]:
        """Retrieves the list of OAuth applications in the specified organization."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.organizationmanager.v1.idp.application.oauth.application_service_pb2.CreateApplicationRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates an OAuth application in the specified organization."""

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.organizationmanager.v1.idp.application.oauth.application_service_pb2.UpdateApplicationRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates the specified OAuth application."""

    @abc.abstractmethod
    def Suspend(
        self,
        request: yandex.cloud.organizationmanager.v1.idp.application.oauth.application_service_pb2.SuspendApplicationRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Sets status to SUSPENDED for the specified OAuth application."""

    @abc.abstractmethod
    def Reactivate(
        self,
        request: yandex.cloud.organizationmanager.v1.idp.application.oauth.application_service_pb2.ReactivateApplicationRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Sets status to ACTIVE for the specified OAuth application."""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.organizationmanager.v1.idp.application.oauth.application_service_pb2.DeleteApplicationRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes the specified OAuth application."""

    @abc.abstractmethod
    def ListOperations(
        self,
        request: yandex.cloud.organizationmanager.v1.idp.application.oauth.application_service_pb2.ListApplicationOperationsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.organizationmanager.v1.idp.application.oauth.application_service_pb2.ListApplicationOperationsResponse, collections.abc.Awaitable[yandex.cloud.organizationmanager.v1.idp.application.oauth.application_service_pb2.ListApplicationOperationsResponse]]:
        """Lists operations for the specified OAuth application."""

    @abc.abstractmethod
    def ListAccessBindings(
        self,
        request: yandex.cloud.access.access_pb2.ListAccessBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.access.access_pb2.ListAccessBindingsResponse, collections.abc.Awaitable[yandex.cloud.access.access_pb2.ListAccessBindingsResponse]]:
        """Lists access bindings for the specified OAuth application."""

    @abc.abstractmethod
    def SetAccessBindings(
        self,
        request: yandex.cloud.access.access_pb2.SetAccessBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Sets access bindings for the specified OAuth application."""

    @abc.abstractmethod
    def UpdateAccessBindings(
        self,
        request: yandex.cloud.access.access_pb2.UpdateAccessBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates access bindings for the specified OAuth application."""

    @abc.abstractmethod
    def ListAssignments(
        self,
        request: yandex.cloud.organizationmanager.v1.idp.application.oauth.application_service_pb2.ListAssignmentsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.organizationmanager.v1.idp.application.oauth.application_service_pb2.ListAssignmentsResponse, collections.abc.Awaitable[yandex.cloud.organizationmanager.v1.idp.application.oauth.application_service_pb2.ListAssignmentsResponse]]:
        """Lists assignmnents for the specified OAuth application."""

    @abc.abstractmethod
    def UpdateAssignments(
        self,
        request: yandex.cloud.organizationmanager.v1.idp.application.oauth.application_service_pb2.UpdateAssignmentsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates assignmnents for the specified OAuth application."""

def add_ApplicationServiceServicer_to_server(servicer: ApplicationServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _MappingType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _MappingTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_MappingType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    MAPPING_TYPE_UNSPECIFIED: _MappingType.ValueType  # 0
    """The mapping type is not specified."""
    DIRECT: _MappingType.ValueType  # 1
    """Direct mapping from source to target."""
    EMPTY: _MappingType.ValueType  # 2
    """Empty mapping (no source attribute)."""

class MappingType(_MappingType, metaclass=_MappingTypeEnumTypeWrapper):
    """Type of attribute mapping."""

MAPPING_TYPE_UNSPECIFIED: MappingType.ValueType  # 0
"""The mapping type is not specified."""
DIRECT: MappingType.ValueType  # 1
"""Direct mapping from source to target."""
EMPTY: MappingType.ValueType  # 2
"""Empty mapping (no source attribute)."""
global___MappingType = MappingType

class _UserTargetAttribute:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _UserTargetAttributeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_UserTargetAttribute.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    USER_TARGET_ATTRIBUTE_UNSPECIFIED: _UserTargetAttribute.ValueType  # 0
    """The target attribute is not specified."""
    FULL_NAME: _UserTargetAttribute.ValueType  # 1
    """Full name attribute."""
    GIVEN_NAME: _UserTargetAttribute.ValueType  # 2
    """Given name attribute."""
    FAMILY_NAME: _UserTargetAttribute.ValueType  # 3
    """Family name attribute."""
    EMAIL: _UserTargetAttribute.ValueType  # 4
    """Email attribute."""
    PHONE_NUMBER: _UserTargetAttribute.ValueType  # 5
    """Phone number attribute."""
    USERNAME: _UserTargetAttribute.ValueType  # 6
    """Username attribute."""
    COMPANY_NAME: _UserTargetAttribute.ValueType  # 7
    """Company name attribute."""
    JOB_TITLE: _UserTargetAttribute.ValueType  # 8
    """Job title attribute."""
    DEPARTMENT: _UserTargetAttribute.ValueType  # 9
    """Department attribute."""
    EMPLOYEE_ID: _UserTargetAttribute.ValueType  # 10
    """Employee ID attribute."""

class UserTargetAttribute(_UserTargetAttribute, metaclass=_UserTargetAttributeEnumTypeWrapper):
    """Target attributes for user mapping."""

USER_TARGET_ATTRIBUTE_UNSPECIFIED: UserTargetAttribute.ValueType  # 0
"""The target attribute is not specified."""
FULL_NAME: UserTargetAttribute.ValueType  # 1
"""Full name attribute."""
GIVEN_NAME: UserTargetAttribute.ValueType  # 2
"""Given name attribute."""
FAMILY_NAME: UserTargetAttribute.ValueType  # 3
"""Family name attribute."""
EMAIL: UserTargetAttribute.ValueType  # 4
"""Email attribute."""
PHONE_NUMBER: UserTargetAttribute.ValueType  # 5
"""Phone number attribute."""
USERNAME: UserTargetAttribute.ValueType  # 6
"""Username attribute."""
COMPANY_NAME: UserTargetAttribute.ValueType  # 7
"""Company name attribute."""
JOB_TITLE: UserTargetAttribute.ValueType  # 8
"""Job title attribute."""
DEPARTMENT: UserTargetAttribute.ValueType  # 9
"""Department attribute."""
EMPLOYEE_ID: UserTargetAttribute.ValueType  # 10
"""Employee ID attribute."""
global___UserTargetAttribute = UserTargetAttribute

class _GroupTargetAttribute:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _GroupTargetAttributeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_GroupTargetAttribute.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    GROUP_TARGET_ATTRIBUTE_UNSPECIFIED: _GroupTargetAttribute.ValueType  # 0
    """The target attribute is not specified."""
    NAME: _GroupTargetAttribute.ValueType  # 1
    """Name attribute."""
    DESCRIPTION: _GroupTargetAttribute.ValueType  # 2
    """Description attribute."""

class GroupTargetAttribute(_GroupTargetAttribute, metaclass=_GroupTargetAttributeEnumTypeWrapper):
    """Target attributes for group mapping."""

GROUP_TARGET_ATTRIBUTE_UNSPECIFIED: GroupTargetAttribute.ValueType  # 0
"""The target attribute is not specified."""
NAME: GroupTargetAttribute.ValueType  # 1
"""Name attribute."""
DESCRIPTION: GroupTargetAttribute.ValueType  # 2
"""Description attribute."""
global___GroupTargetAttribute = GroupTargetAttribute

class _RemoveUserBehavior:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _RemoveUserBehaviorEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_RemoveUserBehavior.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    REMOVE_USER_BEHAVIOR_UNSPECIFIED: _RemoveUserBehavior.ValueType  # 0
    """The behavior is not specified."""
    REMOVE: _RemoveUserBehavior.ValueType  # 1
    """Remove the user."""
    BLOCK: _RemoveUserBehavior.ValueType  # 2
    """Block the user."""

class RemoveUserBehavior(_RemoveUserBehavior, metaclass=_RemoveUserBehaviorEnumTypeWrapper):
    """Behavior when removing users during synchronization."""

REMOVE_USER_BEHAVIOR_UNSPECIFIED: RemoveUserBehavior.ValueType  # 0
"""The behavior is not specified."""
REMOVE: RemoveUserBehavior.ValueType  # 1
"""Remove the user."""
BLOCK: RemoveUserBehavior.ValueType  # 2
"""Block the user."""
global___RemoveUserBehavior = RemoveUserBehavior

class _SessionType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _SessionTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_SessionType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    SESSION_TYPE_UNSPECIFIED: _SessionType.ValueType  # 0
    """The session type is not specified."""
    AD_SYNC: _SessionType.ValueType  # 1
    """Active Directory synchronization session."""
    AD_PASSWORD_HASH: _SessionType.ValueType  # 2
    """Active Directory password hash session."""
    AD_USER_CONTROL: _SessionType.ValueType  # 3
    """Active Directory user control session."""

class SessionType(_SessionType, metaclass=_SessionTypeEnumTypeWrapper):
    """Type of synchronization session."""

SESSION_TYPE_UNSPECIFIED: SessionType.ValueType  # 0
"""The session type is not specified."""
AD_SYNC: SessionType.ValueType  # 1
"""Active Directory synchronization session."""
AD_PASSWORD_HASH: SessionType.ValueType  # 2
"""Active Directory password hash session."""
AD_USER_CONTROL: SessionType.ValueType  # 3
"""Active Directory user control session."""
global___SessionType = SessionType

@typing.final
class SynchronizationSettings(google.protobuf.message.Message):
    """Synchronization settings for a subject container."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUBJECT_CONTAINER_ID_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    REMOVE_USER_BEHAVIOR_FIELD_NUMBER: builtins.int
    SYNCHRONIZATION_INTERVAL_FIELD_NUMBER: builtins.int
    ALLOW_TO_CAPTURE_USERS_FIELD_NUMBER: builtins.int
    ALLOW_TO_CAPTURE_GROUPS_FIELD_NUMBER: builtins.int
    USER_ATTRIBUTE_MAPPINGS_FIELD_NUMBER: builtins.int
    GROUP_ATTRIBUTE_MAPPINGS_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    REPLACEMENT_DOMAIN_FIELD_NUMBER: builtins.int
    subject_container_id: builtins.str
    """ID of the subject container."""
    remove_user_behavior: global___RemoveUserBehavior.ValueType
    """Behavior when removing users."""
    allow_to_capture_users: builtins.bool
    """Whether users can be captured during synchronization."""
    allow_to_capture_groups: builtins.bool
    """Whether groups can be captured during synchronization."""
    replacement_domain: builtins.str
    """Domain replacement configuration."""
    @property
    def filter(self) -> global___SynchronizationFilter:
        """Filter configuration for synchronization."""

    @property
    def synchronization_interval(self) -> google.protobuf.duration_pb2.Duration:
        """Interval between synchronization runs."""

    @property
    def user_attribute_mappings(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___UserAttributeMapping]:
        """User attribute mappings."""

    @property
    def group_attribute_mappings(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___GroupAttributeMapping]:
        """Group attribute mappings."""

    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Timestamp when the settings were created."""

    def __init__(
        self,
        *,
        subject_container_id: builtins.str = ...,
        filter: global___SynchronizationFilter | None = ...,
        remove_user_behavior: global___RemoveUserBehavior.ValueType = ...,
        synchronization_interval: google.protobuf.duration_pb2.Duration | None = ...,
        allow_to_capture_users: builtins.bool = ...,
        allow_to_capture_groups: builtins.bool = ...,
        user_attribute_mappings: collections.abc.Iterable[global___UserAttributeMapping] | None = ...,
        group_attribute_mappings: collections.abc.Iterable[global___GroupAttributeMapping] | None = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        replacement_domain: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at", "filter", b"filter", "synchronization_interval", b"synchronization_interval"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["allow_to_capture_groups", b"allow_to_capture_groups", "allow_to_capture_users", b"allow_to_capture_users", "created_at", b"created_at", "filter", b"filter", "group_attribute_mappings", b"group_attribute_mappings", "remove_user_behavior", b"remove_user_behavior", "replacement_domain", b"replacement_domain", "subject_container_id", b"subject_container_id", "synchronization_interval", b"synchronization_interval", "user_attribute_mappings", b"user_attribute_mappings"]) -> None: ...

global___SynchronizationSettings = SynchronizationSettings

@typing.final
class SynchronizationFilter(google.protobuf.message.Message):
    """Filter configuration for synchronization."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DOMAIN_FIELD_NUMBER: builtins.int
    GROUPS_FIELD_NUMBER: builtins.int
    ORGANIZATION_UNITS_FIELD_NUMBER: builtins.int
    domain: builtins.str
    """Domain to synchronize."""
    @property
    def groups(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of groups to synchronize."""

    @property
    def organization_units(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of organizational units to synchronize."""

    def __init__(
        self,
        *,
        domain: builtins.str = ...,
        groups: collections.abc.Iterable[builtins.str] | None = ...,
        organization_units: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["domain", b"domain", "groups", b"groups", "organization_units", b"organization_units"]) -> None: ...

global___SynchronizationFilter = SynchronizationFilter

@typing.final
class UserAttributeMapping(google.protobuf.message.Message):
    """User attribute mapping configuration."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SOURCE_FIELD_NUMBER: builtins.int
    TARGET_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    source: builtins.str
    """Source attribute name."""
    target: global___UserTargetAttribute.ValueType
    """Target attribute to map to."""
    type: global___MappingType.ValueType
    """Type of mapping."""
    def __init__(
        self,
        *,
        source: builtins.str = ...,
        target: global___UserTargetAttribute.ValueType = ...,
        type: global___MappingType.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["source", b"source", "target", b"target", "type", b"type"]) -> None: ...

global___UserAttributeMapping = UserAttributeMapping

@typing.final
class GroupAttributeMapping(google.protobuf.message.Message):
    """Group attribute mapping configuration."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SOURCE_FIELD_NUMBER: builtins.int
    TARGET_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    source: builtins.str
    """Source attribute name."""
    target: global___GroupTargetAttribute.ValueType
    """Target attribute to map to."""
    type: global___MappingType.ValueType
    """Type of mapping."""
    def __init__(
        self,
        *,
        source: builtins.str = ...,
        target: global___GroupTargetAttribute.ValueType = ...,
        type: global___MappingType.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["source", b"source", "target", b"target", "type", b"type"]) -> None: ...

global___GroupAttributeMapping = GroupAttributeMapping



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.message
import google.protobuf.timestamp_pb2
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class CreateEphemeralAccessKeyRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUBJECT_ID_FIELD_NUMBER: builtins.int
    SESSION_NAME_FIELD_NUMBER: builtins.int
    POLICY_FIELD_NUMBER: builtins.int
    DURATION_FIELD_NUMBER: builtins.int
    subject_id: builtins.str
    """The subject identifier for whom the ephemeral access key will be created.
    If not specified, it defaults to the subject that made the request.
    """
    session_name: builtins.str
    """Use the session name to uniquely identify a session when the same SA is impersonated by different principals or for different reasons
    Pattern: [\\w+=,.@-]*
    """
    policy: builtins.str
    """AWS-compatible policy in JSON format that you want to use as an inline session policy."""
    @property
    def duration(self) -> google.protobuf.duration_pb2.Duration:
        """Duration, which specifies the duration of the ephemeral access key,
        but duration won't be longer than the lifetime of the authentication token that made the request
        """

    def __init__(
        self,
        *,
        subject_id: builtins.str = ...,
        session_name: builtins.str = ...,
        policy: builtins.str = ...,
        duration: google.protobuf.duration_pb2.Duration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["duration", b"duration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["duration", b"duration", "policy", b"policy", "session_name", b"session_name", "subject_id", b"subject_id"]) -> None: ...

global___CreateEphemeralAccessKeyRequest = CreateEphemeralAccessKeyRequest

@typing.final
class CreateEphemeralAccessKeyResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACCESS_KEY_ID_FIELD_NUMBER: builtins.int
    SECRET_FIELD_NUMBER: builtins.int
    SESSION_TOKEN_FIELD_NUMBER: builtins.int
    EXPIRES_AT_FIELD_NUMBER: builtins.int
    access_key_id: builtins.str
    """ID of the access key.
    The key is AWS compatible.
    """
    secret: builtins.str
    """Secret access key.
    The key is AWS compatible.
    """
    session_token: builtins.str
    """Session token.
    The token is AWS compatible. Should be attached to any call made by provided credentials.
    """
    @property
    def expires_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Expiration time.
        The date on which the current credentials expire.
        """

    def __init__(
        self,
        *,
        access_key_id: builtins.str = ...,
        secret: builtins.str = ...,
        session_token: builtins.str = ...,
        expires_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["expires_at", b"expires_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["access_key_id", b"access_key_id", "expires_at", b"expires_at", "secret", b"secret", "session_token", b"session_token"]) -> None: ...

global___CreateEphemeralAccessKeyResponse = CreateEphemeralAccessKeyResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class LogSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLOUD_LOG_GROUP_ID_FIELD_NUMBER: builtins.int
    cloud_log_group_id: builtins.str
    """Id of Yandex Cloud log group to upload agent logs to"""
    def __init__(
        self,
        *,
        cloud_log_group_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cloud_log_group_id", b"cloud_log_group_id"]) -> None: ...

global___LogSettings = LogSettings



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.dns.v1.dns_firewall_pb2
import yandex.cloud.operation.operation_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetDnsFirewallRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DNS_FIREWALL_ID_FIELD_NUMBER: builtins.int
    dns_firewall_id: builtins.str
    """ID of the DNS firewall to return.

    To get a DNS firewall ID, make a [DnsFirewallService.List] request.
    """
    def __init__(
        self,
        *,
        dns_firewall_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["dns_firewall_id", b"dns_firewall_id"]) -> None: ...

global___GetDnsFirewallRequest = GetDnsFirewallRequest

@typing.final
class ListDnsFirewallsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to list DNS firewalls in.

    To get the folder ID use a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than `page_size`, the service returns a [ListDnsFirewallsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set `page_token` to the 
    [ListDnsFirewallsResponse.next_page_token] returned by a previous list request.
    """
    filter: builtins.str
    """A filter expression that filters DNS firewalls listed in the response.

    The expression must specify: 
    1. The field name. Currently you can use filtering only on the [DnsFirewall.name] field.
    2. An `=` operator.
    3. The value in double quotes (`"`). Must be 3-63 characters long and match the regular expression `[a-z][-a-z0-9]{1,61}[a-z0-9]`.
    Example of a filter: `name=my-dns-firewall`.
    """
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "folder_id", b"folder_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListDnsFirewallsRequest = ListDnsFirewallsRequest

@typing.final
class ListDnsFirewallsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DNS_FIREWALLS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of the list. If the number of results is greater than
    the specified [ListDnsFirewallsRequest.page_size], use `next_page_token` as the value
    for the [ListDnsFirewallsRequest.page_token] parameter in the next list request.

    Each subsequent page will have its own `next_page_token` to continue paging through the results.
    """
    @property
    def dns_firewalls(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.dns.v1.dns_firewall_pb2.DnsFirewall]:
        """List of DNS firewalls in the specified folder."""

    def __init__(
        self,
        *,
        dns_firewalls: collections.abc.Iterable[yandex.cloud.dns.v1.dns_firewall_pb2.DnsFirewall] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["dns_firewalls", b"dns_firewalls", "next_page_token", b"next_page_token"]) -> None: ...

global___ListDnsFirewallsResponse = ListDnsFirewallsResponse

@typing.final
class CreateDnsFirewallRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    FOLDER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    DELETION_PROTECTION_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    RESOURCE_CONFIG_FIELD_NUMBER: builtins.int
    WHITELIST_FQDNS_FIELD_NUMBER: builtins.int
    BLACKLIST_FQDNS_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to create DNS firewalls in.

    To get a folder ID, make a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    name: builtins.str
    """Name of the DNS firewall.
    The name must be unique within the folder.
    """
    description: builtins.str
    """Description of the DNS firewall."""
    deletion_protection: builtins.bool
    """Prevents accidental firewall removal."""
    enabled: builtins.bool
    """Whether the DNS firewall is enabled."""
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """DNS firewall labels as `key:value` pairs."""

    @property
    def resource_config(self) -> yandex.cloud.dns.v1.dns_firewall_pb2.DnsFirewall.ResourceConfig:
        """Resource settings.
        Specifies resources that the DNS firewall applies to.
        """

    @property
    def whitelist_fqdns(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of FQDNs that the DNS firewall allows to pass."""

    @property
    def blacklist_fqdns(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of FQDNs that the DNS firewall blocks."""

    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        deletion_protection: builtins.bool = ...,
        enabled: builtins.bool = ...,
        resource_config: yandex.cloud.dns.v1.dns_firewall_pb2.DnsFirewall.ResourceConfig | None = ...,
        whitelist_fqdns: collections.abc.Iterable[builtins.str] | None = ...,
        blacklist_fqdns: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["resource_config", b"resource_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["blacklist_fqdns", b"blacklist_fqdns", "deletion_protection", b"deletion_protection", "description", b"description", "enabled", b"enabled", "folder_id", b"folder_id", "labels", b"labels", "name", b"name", "resource_config", b"resource_config", "whitelist_fqdns", b"whitelist_fqdns"]) -> None: ...

global___CreateDnsFirewallRequest = CreateDnsFirewallRequest

@typing.final
class CreateDnsFirewallMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DNS_FIREWALL_ID_FIELD_NUMBER: builtins.int
    dns_firewall_id: builtins.str
    """ID of the DNS firewall that is being created."""
    def __init__(
        self,
        *,
        dns_firewall_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["dns_firewall_id", b"dns_firewall_id"]) -> None: ...

global___CreateDnsFirewallMetadata = CreateDnsFirewallMetadata

@typing.final
class UpdateDnsFirewallRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    DNS_FIREWALL_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    DELETION_PROTECTION_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    RESOURCE_CONFIG_FIELD_NUMBER: builtins.int
    WHITELIST_FQDNS_FIELD_NUMBER: builtins.int
    BLACKLIST_FQDNS_FIELD_NUMBER: builtins.int
    dns_firewall_id: builtins.str
    """ID of the DNS firewall to update.
     
    To get the DNS firewall ID, make a [DnsFirewallService.List] request.
    """
    name: builtins.str
    """New name for the DNS firewall.
    The name must be unique within the folder.
    """
    description: builtins.str
    """New description of the DNS firewall."""
    deletion_protection: builtins.bool
    """Prevents accidental firewall removal."""
    enabled: builtins.bool
    """Whether the DNS firewall is enabled."""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask specifying which fields of the DNS firewall resource are going to be updated."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """DNS firewall labels as `key:value` pairs.

        Existing set of labels is completely replaced by the provided set, so if you just want
        to add or remove a label:
        1. Get the current set of labels with a [DnsFirewallService.Get] request.
        2. Add or remove a label in this set.
        3. Send the new set in this field.
        """

    @property
    def resource_config(self) -> yandex.cloud.dns.v1.dns_firewall_pb2.DnsFirewall.ResourceConfig:
        """Resource settings.
        Specifies resources that the DNS firewall applies to.
        """

    @property
    def whitelist_fqdns(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of FQDNs that the DNS firewall allows to pass."""

    @property
    def blacklist_fqdns(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of FQDNs that the DNS firewall blocks."""

    def __init__(
        self,
        *,
        dns_firewall_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        deletion_protection: builtins.bool = ...,
        enabled: builtins.bool = ...,
        resource_config: yandex.cloud.dns.v1.dns_firewall_pb2.DnsFirewall.ResourceConfig | None = ...,
        whitelist_fqdns: collections.abc.Iterable[builtins.str] | None = ...,
        blacklist_fqdns: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["resource_config", b"resource_config", "update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["blacklist_fqdns", b"blacklist_fqdns", "deletion_protection", b"deletion_protection", "description", b"description", "dns_firewall_id", b"dns_firewall_id", "enabled", b"enabled", "labels", b"labels", "name", b"name", "resource_config", b"resource_config", "update_mask", b"update_mask", "whitelist_fqdns", b"whitelist_fqdns"]) -> None: ...

global___UpdateDnsFirewallRequest = UpdateDnsFirewallRequest

@typing.final
class UpdateDnsFirewallMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DNS_FIREWALL_ID_FIELD_NUMBER: builtins.int
    dns_firewall_id: builtins.str
    """ID of the DNS firewall that is being updated."""
    def __init__(
        self,
        *,
        dns_firewall_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["dns_firewall_id", b"dns_firewall_id"]) -> None: ...

global___UpdateDnsFirewallMetadata = UpdateDnsFirewallMetadata

@typing.final
class MoveDnsFirewallRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DNS_FIREWALL_ID_FIELD_NUMBER: builtins.int
    DESTINATION_FOLDER_ID_FIELD_NUMBER: builtins.int
    dns_firewall_id: builtins.str
    """ID of the DNS firewall to move.

    To get the DNS firewall ID, make a [DnsFirewallService.List] request.
    """
    destination_folder_id: builtins.str
    """ID of the folder to move the firewall to.

    To get the folder ID, make a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    def __init__(
        self,
        *,
        dns_firewall_id: builtins.str = ...,
        destination_folder_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["destination_folder_id", b"destination_folder_id", "dns_firewall_id", b"dns_firewall_id"]) -> None: ...

global___MoveDnsFirewallRequest = MoveDnsFirewallRequest

@typing.final
class MoveDnsFirewallMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DNS_FIREWALL_ID_FIELD_NUMBER: builtins.int
    dns_firewall_id: builtins.str
    """ID of the DNS firewall that is being moved."""
    def __init__(
        self,
        *,
        dns_firewall_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["dns_firewall_id", b"dns_firewall_id"]) -> None: ...

global___MoveDnsFirewallMetadata = MoveDnsFirewallMetadata

@typing.final
class DeleteDnsFirewallRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DNS_FIREWALL_ID_FIELD_NUMBER: builtins.int
    dns_firewall_id: builtins.str
    """ID of the DNS firewall to delete.

    To get a DNS firewall ID, make a [DnsFirewallService.List] request.
    """
    def __init__(
        self,
        *,
        dns_firewall_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["dns_firewall_id", b"dns_firewall_id"]) -> None: ...

global___DeleteDnsFirewallRequest = DeleteDnsFirewallRequest

@typing.final
class DeleteDnsFirewallMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DNS_FIREWALL_ID_FIELD_NUMBER: builtins.int
    dns_firewall_id: builtins.str
    """ID of the DNS firewall that is being deleted."""
    def __init__(
        self,
        *,
        dns_firewall_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["dns_firewall_id", b"dns_firewall_id"]) -> None: ...

global___DeleteDnsFirewallMetadata = DeleteDnsFirewallMetadata

@typing.final
class ListDnsFirewallOperationsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DNS_FIREWALL_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    dns_firewall_id: builtins.str
    """ID of the DNS firewall to list operations for.

    To get a DNS firewall ID, make a [DnsFirewallService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size], the service returns a [ListDnsFirewallOperationsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token] to the 
    [ListDnsFirewallOperationsResponse.next_page_token] returned by a previous list request.
    """
    filter: builtins.str
    """A filter expression that filters DNS firewalls listed in the response.

    The expression must specify: 
    1. The field name. Currently you can use filtering only on the [DnsFirewall.name] field.
    2. An `=` operator.
    3. The value in double quotes (`"`). Must be 3-63 characters long and match the regular expression `[a-z][-a-z0-9]{1,61}[a-z0-9]`.
    Example of a filter: `name=my-dns-firewall`.
    """
    def __init__(
        self,
        *,
        dns_firewall_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["dns_firewall_id", b"dns_firewall_id", "filter", b"filter", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListDnsFirewallOperationsRequest = ListDnsFirewallOperationsRequest

@typing.final
class ListDnsFirewallOperationsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPERATIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of the list. If the number of results is greater than
    the specified [ListDnsFirewallOperationsRequest.page_size], use `next_page_token` as the value
    for the [ListDnsFirewallOperationsRequest.page_token] parameter in the next list request.

    Each subsequent page will have its own `next_page_token` to continue paging through the results.
    """
    @property
    def operations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.operation.operation_pb2.Operation]:
        """List of operations for the specified DNS firewall."""

    def __init__(
        self,
        *,
        operations: collections.abc.Iterable[yandex.cloud.operation.operation_pb2.Operation] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "operations", b"operations"]) -> None: ...

global___ListDnsFirewallOperationsResponse = ListDnsFirewallOperationsResponse



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/devtools/ycvc/v1/control_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/devtools/ycvc/v1/control_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3yandex/cloud/devtools/ycvc/v1/control_service.proto\x12\x1dyandex.cloud.devtools.ycvc.v1\x1a\x1dyandex/cloud/validation.proto\x1a\x1cgoogle/api/annotations.proto\"=\n\x0bInitRequest\x12\x17\n\ttool_name\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x15\n\x07version\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\"\x97\x01\n\x0cInitResponse\x12[\n\x13\x64\x65precation_warning\x18\x01 \x01(\x0b\x32>.yandex.cloud.devtools.ycvc.v1.InitResponse.DeprecationWarning\x1a*\n\x12\x44\x65precationWarning\x12\x14\n\x06reason\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x32\xaf\x01\n\x15VersionControlService\x12\x95\x01\n\x04Init\x12*.yandex.cloud.devtools.ycvc.v1.InitRequest\x1a+.yandex.cloud.devtools.ycvc.v1.InitResponse\"4\x82\xd3\xe4\x93\x02.\")/v1/obsolete_collections/{tool_name}:init:\x01*B\x89\x01\n!yandex.cloud.api.devtools.ycvc.v1B\x1aVersionControlServiceProtoP\x01ZFgithub.com/yandex-cloud/go-genproto/yandex/cloud/devtools/ycvc/v1;ycvcb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.devtools.ycvc.v1.control_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n!yandex.cloud.api.devtools.ycvc.v1B\032VersionControlServiceProtoP\001ZFgithub.com/yandex-cloud/go-genproto/yandex/cloud/devtools/ycvc/v1;ycvc'
  _globals['_INITREQUEST'].fields_by_name['tool_name']._loaded_options = None
  _globals['_INITREQUEST'].fields_by_name['tool_name']._serialized_options = b'\350\3071\001'
  _globals['_INITREQUEST'].fields_by_name['version']._loaded_options = None
  _globals['_INITREQUEST'].fields_by_name['version']._serialized_options = b'\350\3071\001'
  _globals['_INITRESPONSE_DEPRECATIONWARNING'].fields_by_name['reason']._loaded_options = None
  _globals['_INITRESPONSE_DEPRECATIONWARNING'].fields_by_name['reason']._serialized_options = b'\350\3071\001'
  _globals['_VERSIONCONTROLSERVICE'].methods_by_name['Init']._loaded_options = None
  _globals['_VERSIONCONTROLSERVICE'].methods_by_name['Init']._serialized_options = b'\202\323\344\223\002.\")/v1/obsolete_collections/{tool_name}:init:\001*'
  _globals['_INITREQUEST']._serialized_start=147
  _globals['_INITREQUEST']._serialized_end=208
  _globals['_INITRESPONSE']._serialized_start=211
  _globals['_INITRESPONSE']._serialized_end=362
  _globals['_INITRESPONSE_DEPRECATIONWARNING']._serialized_start=320
  _globals['_INITRESPONSE_DEPRECATIONWARNING']._serialized_end=362
  _globals['_VERSIONCONTROLSERVICE']._serialized_start=365
  _globals['_VERSIONCONTROLSERVICE']._serialized_end=540
# @@protoc_insertion_point(module_scope)
